==> xcsoar-6.6.tar.bz2: xcsoar-6.6/src/Computer/ConditionMonitor/ConditionMonitorWind.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_CONDITION_MONITOR_WIND_HPP
#define XCSOAR_CONDITION_MONITOR_WIND_HPP

#include "ConditionMonitor.hpp"
#include "Geo/SpeedVector.hpp"

/** #ConditionMonitor to track/warn on significant changes in wind speed */
class ConditionMonitorWind final : public ConditionMonitor {
  SpeedVector wind;
  SpeedVector last_wind;

public:
  constexpr ConditionMonitorWind()
    :ConditionMonitor(60 * 5, 10),
     wind(SpeedVector::Zero()), last_wind(SpeedVector::Zero()) {}

protected:
  virtual bool CheckCondition(const NMEAInfo &basic,
                              const DerivedInfo &calculated,
                              const ComputerSettings &settings) override;
  virtual void Notify();
  virtual void SaveLast();
};

#endif

==> xcsoar-6.7.7.tar.bz2: xcsoar-6.7.7/src/Computer/ConditionMonitor/ConditionMonitorWind.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_CONDITION_MONITOR_WIND_HPP
#define XCSOAR_CONDITION_MONITOR_WIND_HPP

#include "ConditionMonitor.hpp"
#include "Geo/SpeedVector.hpp"

/** #ConditionMonitor to track/warn on significant changes in wind speed */
class ConditionMonitorWind final : public ConditionMonitor {
  SpeedVector wind;
  SpeedVector last_wind;

public:
  constexpr ConditionMonitorWind()
    :ConditionMonitor(60 * 5, 10),
     wind(SpeedVector::Zero()), last_wind(SpeedVector::Zero()) {}

protected:
  bool CheckCondition(const NMEAInfo &basic,
                      const DerivedInfo &calculated,
                      const ComputerSettings &settings) override;
  void Notify() override;
  void SaveLast() override;
};

#endif
